@@ -2,14 +2,19 @@ s3_headers <- function(board, verb, path, file) {
   date <- format(Sys.time(), "%a, %d %b %Y %H:%M:%S %z")
 
   # allow full urls to allow arbitrary file downloads
-  path <- gsub(paste0(board$url, "/"), "", path, fixed = TRUE)
+  bucket <- board$bucket
+  if (grepl("^https?://", path)) {
+    path_nohttp <-  gsub("^https?://", "", path)
+    path <- gsub("^[^/]+/", "", path_nohttp)
+    bucket <- gsub("\\..*", "", path_nohttp)
+  }
 
   content <- paste(
     verb,
     "",
     "application/octet-stream",
     date,
-    file.path("", board$bucket, path),
+    file.path("", bucket, path),
     sep = "\n"
   )
 
@@ -17,7 +22,7 @@ s3_headers <- function(board, verb, path, file) {
     base64enc::base64encode()
 
   headers <- httr::add_headers(
-    Host = paste0(board$bucket, ".s3.amazonaws.com"),
+    Host = paste0(bucket, ".", board$host),
     Date = date,
     `Content-Type` = "application/octet-stream",
     Authorization = paste0("AWS ", board$key, ":", signature)
@@ -31,6 +36,7 @@ board_initialize.s3 <- function(board,
                                 key = Sys.getenv("AWS_ACCESS_KEY_ID"),
                                 secret = Sys.getenv("AWS_SECRET_ACCESS_KEY"),
                                 cache = NULL,
+                                host = "s3.amazonaws.com",
                                 ...) {
   board$bucket <- bucket
   if (nchar(bucket) == 0) stop("The 's3' board requires a 'bucket' parameter.")
@@ -38,7 +44,7 @@ board_initialize.s3 <- function(board,
   if (nchar(key) == 0)  stop("The 's3' board requires a 'key' parameter.")
   if (nchar(secret) == 0)  stop("The 's3' board requires a 'secret' parameter.")
 
-  s3_url <- paste0("http://", board$bucket, ".s3.amazonaws.com")
+  s3_url <- paste0("http://", board$bucket, ".", host)
 
   board_register_datatxt(name = board$name,
                          url = s3_url,
@@ -49,7 +55,9 @@ board_initialize.s3 <- function(board,
                          secret = secret,
                          bucket = bucket,
                          connect = FALSE,
-                         browse_url = paste0("https://s3.console.aws.amazon.com/s3/buckets/", bucket, "/"))
+                         browse_url = paste0("https://s3.console.aws.amazon.com/s3/buckets/", bucket, "/"),
+                         host = host,
+                         ...)
 
   board_get(board$name)
 }
