@@ -1,7 +1,9 @@
 pin_load.files <- function(path, ...) {
   files <- dir(path, recursive = TRUE, full.names = TRUE)
 
-  files[!grepl("data\\.txt$", files)]
+  result <- files[!grepl("data\\.txt$", files)]
+
+  format_tibble(result)
 }
 
 #' @keywords internal
